==> litejs-0.9.2.tgz: package/public/views/components/material.js <==

!function(Mediator) {
	var openMenu, lastMenuTarget
	, tooltip = El("pre.tooltip").to(document.body)
	, tick, wait
	, ripple = El(".waves-ripple")

	El.near = near
	function near(source, target, x, y, margin) {
		var top, left
		, rect = target.getBoundingClientRect()
		if (x == "left") {
			left = rect.left - (source.offsetWidth) - margin
			x = "150%"
		} else if (x == "leftEdge") {
			left = rect.left - margin
			x = "0%"
		} else if (x == "right") {
			left = rect.left + target.offsetWidth + margin
			x = "-50%"
		} else if (x == "rightEdge") {
			left = rect.left - source.offsetWidth + target.offsetWidth + margin
			x = "100%"
		} else {
			left = rect.left + (target.offsetWidth/2) - (source.offsetWidth/2)
			x = "50%"
		}
		if (y == "top") {
			top = rect.top - (source.offsetHeight) - margin
			y = " 150%"
		} else if (y == "bottom") {
			top = rect.top + target.offsetHeight + margin
			y = " -50%"
		} else {
			top = rect.top + (target.offsetHeight/2) - (source.offsetHeight/2)
			y = " 50%"
		}
		left += El.scrollLeft()
		top += El.scrollTop()
		source.css("transform-origin", x + y)
		source.css("top", (top < 0 ? 0 : top) + "px")
		source.css("left", (left < 0 ? 0 : left) + "px")
	}
	document.body.on("mouseover", function(e) {
		var x, y
		, target = e.target
		, text = target.getAttribute("data-tooltip")
		tooltip.rmClass("is-visible")
		if (!text) return
		tooltip.empty().append(text)
		if (target.hasClass("tooltip--left")) {
			x = "left"
		} else if (target.hasClass("tooltip--right")) {
			x = "right"
		} else if (target.hasClass("tooltip--top")) {
			y = "top"
		} else {
			y = "bottom"
		}
		near(tooltip, target, x, y, 4)
		setTimeout(function() {
			tooltip.addClass("is-visible")
		}, 0)
	})
	function closeMenu(e) {
		if (e && e.target == lastMenuTarget) return
		var menu = openMenu
		if (menu) {
			menu.rmClass("is-visible")
			setTimeout(menu.kill.bind(menu), 800)
		}
		if (lastMenuTarget) {
			lastMenuTarget.rmClass("is-active")
		}
		openMenu = null
	}
	Mediator.on("resize", closeMenu)
	Mediator.on("showMenu", function(target, menu, x, y, margin, e) {
		Event.stop(e)
		var close = openMenu && lastMenuTarget == target
		closeMenu()
		if (close) return
		lastMenuTarget = target
		openMenu = El(menu).to(document.body).render()
		near(openMenu, target, x, y, 4)
		target.addClass("is-active")
		setTimeout(function() {
			openMenu.addClass("is-visible")
		}, 0)
	})
	document.body.on("mouseup", closeMenu)

	document.body.on("mousedown", function(e) {
		var target = e.target
		if (!target.hasClass("waves") || target.disabled) return
		var rect = target.getBoundingClientRect()
		, top = e.clientY - rect.top
		, left = e.clientX - rect.left
		, maxH = Math.max(top, target.offsetHeight - top)
		, maxW = Math.max(left, target.offsetWidth - left)
		, max = Math.sqrt(maxH * maxH + maxW * maxW)
		, size = (2 * max) + "px"
		ripple.css("top", (top - max) + "px")
		ripple.css("left", (left - max) + "px")
		ripple.css("width", size)
		ripple.css("height", size)
		ripple.to(target)
		clearTimeout(tick)
		end()
		wait = 1
		tick = setTimeout(end, 600)
		document.body.one("mouseup", end)
		setTimeout(function() {
			ripple.addClass("waves-ripple--play")
		}, 0)
	})
	function end() {
		if (!(wait--)) {
			ripple.rmClass("waves-ripple--play")
		}
	}
}(Mediator)

==> litejs-0.12.0.tgz: package/public/views/components/material.js <==

!function(Mediator) {
	var openMenu, lastMenuTarget
	, tooltip = El("pre.tooltip").to(document.body)
	, tick, wait
	, ripple = El(".waves-ripple")

	El.near = near
	function near(source, target, x, y, margin) {
		var top, left
		, rect = target.getBoundingClientRect()
		if (x == "left") {
			left = rect.left - (source.offsetWidth) - margin
			x = "150%"
		} else if (x == "leftEdge") {
			left = rect.left - margin
			x = "0%"
		} else if (x == "right") {
			left = rect.left + rect.width + margin
			x = "-50%"
		} else if (x == "rightEdge") {
			left = rect.left - source.offsetWidth + rect.width + margin
			x = "100%"
		} else {
			// svg elements dont have offsetWidth
			left = rect.left + (rect.width / 2) - (source.offsetWidth/2)
			x = "50%"
		}
		if (y == "top") {
			top = rect.top - source.offsetHeight - margin
			y = " 150%"
		} else if (y == "bottom") {
			top = rect.top + rect.height + margin
			y = " -50%"
		} else {
			top = rect.top + (rect.height / 2) - (source.offsetHeight/2)
			y = " 50%"
		}
		left += El.scrollLeft()
		top += El.scrollTop()
		source.css("transform-origin", x + y)
		source.css("top", (top < 0 ? 0 : top) + "px")
		source.css("left", (left < 0 ? 0 : left) + "px")
	}
	document.body.on("mouseover", function(e) {
		var x, y
		, target = e.target
		, text = target.getAttribute("data-tooltip")
		tooltip.rmClass("is-visible")
		if (!text) return
		tooltip.empty().append(text)
		if (target.hasClass("tooltip--left")) {
			x = "left"
		} else if (target.hasClass("tooltip--right")) {
			x = "right"
		} else if (target.hasClass("tooltip--top")) {
			y = "top"
		} else {
			y = "bottom"
		}
		near(tooltip, target, x, y, 4)
		setTimeout(function() {
			tooltip.addClass("is-visible")
		}, 0)
	})
	function closeMenu(e) {
		if (e && e.target == lastMenuTarget) return
		var menu = openMenu
		if (menu) {
			menu.rmClass("is-visible")
			setTimeout(menu.kill.bind(menu), 800)
		}
		if (lastMenuTarget) {
			lastMenuTarget.rmClass("is-active")
		}
		openMenu = null
	}
	Mediator.on("resize", closeMenu)
	Mediator.on("showMenu", function(target, menu, x, y, margin, e) {
		Event.stop(e)
		var close = openMenu && lastMenuTarget == target
		closeMenu()
		if (close) return
		lastMenuTarget = target
		openMenu = El(menu).to(document.body).render()
		near(openMenu, target, x, y, 4)
		target.addClass("is-active")
		setTimeout(function() {
			openMenu.addClass("is-visible")
		}, 0)
	})
	document.body.on("mouseup", closeMenu)

	document.body.on("mousedown", function(e) {
		var target = e.target
		if (!target.hasClass("waves") || target.disabled) return
		var rect = target.getBoundingClientRect()
		, top = e.clientY - rect.top
		, left = e.clientX - rect.left
		, maxH = Math.max(top, target.offsetHeight - top)
		, maxW = Math.max(left, target.offsetWidth - left)
		, max = Math.sqrt(maxH * maxH + maxW * maxW)
		, size = (2 * max) + "px"
		ripple.css("top", (top - max) + "px")
		ripple.css("left", (left - max) + "px")
		ripple.css("width", size)
		ripple.css("height", size)
		ripple.to(target)
		clearTimeout(tick)
		end()
		wait = 1
		tick = setTimeout(end, 800)
		document.body.one("mouseup", end)
		setTimeout(function() {
			ripple.addClass("waves-ripple--play")
		}, 0)
	})
	function end() {
		if (!(wait--)) {
			ripple.rmClass("waves-ripple--play")
		}
	}
}(Mediator)
